@@ -61,6 +61,7 @@
 #include <QtCore/QTimer>
 #include <QtCore/QThread>
 #include <QtQuick/QQuickWindow>
+#include <QtWidgets/QGraphicsLayout>
 
 QT_CHARTS_BEGIN_NAMESPACE
 
@@ -211,7 +212,9 @@ QT_CHARTS_BEGIN_NAMESPACE
   \qmlproperty rect ChartView::plotArea
   The rectangle within which the chart is drawn.
 
-  The plot area does not include the area defined by margins.
+  The plot area does not include the area defined by margins. By default this will resize if inside
+  a ChartView. If an explicit rectangle is set for the plot area then it will respect this, to revert
+  back to the default behavior, then setting it to \c{Qt.rect(0, 0, 0, 0)} will achieve this.
 
   \sa margins
 */
@@ -323,22 +326,22 @@ QT_CHARTS_BEGIN_NAMESPACE
 
 /*!
   \qmlmethod Axis ChartView::axisX(AbstractSeries series)
-  The x-axis of the series.
+  The x-axis of the \a series.
 */
 
 /*!
   \qmlmethod ChartView::setAxisX(AbstractAxis axis, AbstractSeries series)
-  Sets the x-axis of the series.
+  Sets the x-axis of the \a series to \a axis.
 */
 
 /*!
   \qmlmethod Axis ChartView::axisY(AbstractSeries series)
-  The y-axis of the series.
+  The y-axis of the \a series.
 */
 
 /*!
   \qmlmethod ChartView::setAxisY(AbstractAxis axis, AbstractSeries series)
-  Sets the y-axis of the series.
+  Sets the y-axis of the \a series to \a axis.
 */
 
 /*!
@@ -364,6 +367,7 @@ QT_CHARTS_BEGIN_NAMESPACE
 /*!
   \qmlmethod ChartView::zoomOut()
   Zooms out of the view by a factor of two.
+  \note This will do nothing if the result would contain an invalid logarithmic axis range.
 */
 
 /*!
@@ -439,6 +443,23 @@ DeclarativeChart::DeclarativeChart(QChart::ChartType type, QQuickItem *parent)
     initChart(type);
 }
 
+// QTBUG-71013
+// The symbol resides in qbarmodelmapper.cpp#548 in the C++ module.
+// Here, it gets imported and reset to the DeclarativeBarSet allocator
+#if defined(Q_OS_WIN) && !defined(QT_STATIC)
+Q_CHARTS_EXPORT
+#else
+extern
+#endif
+QBarSet *(*qt_allocate_bar_set)(const QString &label);
+
+QBarSet *qt_allocate_bar_set_qml(const QString &label)
+{
+    auto bar = new DeclarativeBarSet();
+    bar->setLabel(label);
+    return bar;
+}
+
 void DeclarativeChart::initChart(QChart::ChartType type)
 {
     m_sceneImage = 0;
@@ -450,6 +471,10 @@ void DeclarativeChart::initChart(QChart::ChartType type)
 
     setFlag(ItemHasContents, true);
 
+    // Reset allocator for QBarSet to create
+    // Declarative BarSets by default
+    qt_allocate_bar_set = &qt_allocate_bar_set_qml;
+
     if (type == QChart::ChartTypePolar)
         m_chart = new QPolarChart();
     else
@@ -608,9 +633,12 @@ void DeclarativeChart::seriesAxisAttachHelper(QAbstractSeries *series, QAbstract
 {
     if (!series->attachedAxes().contains(axis)) {
         // Remove & delete old axes that are not attached to any other series
+        // Detach old axis from series so that if it is shared with other series
+        // It can be deleted.
         foreach (QAbstractAxis* oldAxis, m_chart->axes(orientation, series)) {
             bool otherAttachments = false;
             if (oldAxis != axis) {
+                series->detachAxis(oldAxis);
                 foreach (QAbstractSeries *oldSeries, m_chart->series()) {
                     if (oldSeries != series && oldSeries->attachedAxes().contains(oldAxis)) {
                         otherAttachments = true;
@@ -1469,6 +1497,15 @@ QPointF DeclarativeChart::mapToPosition(const QPointF &value, QAbstractSeries *s
     return m_chart->mapToPosition(value, series);
 }
 
-#include "moc_declarativechart_p.cpp"
+void DeclarativeChart::setPlotArea(const QRectF &rect)
+{
+    m_chart->setPlotArea(rect);
+
+    // If plotArea is set inside ChartView, contentGeometry is updated too early and we end up
+    // with incorrect plotArea. Invalidate the layout to correct the geometry.
+    m_chart->layout()->invalidate();
+}
 
 QT_CHARTS_END_NAMESPACE
+
+#include "moc_declarativechart_p.cpp"
