@@ -144,7 +144,8 @@ void tst_QAbstractAxis::axisPen()
     QCOMPARE(spy10.count(), 0);
     QCOMPARE(spy11.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
     //TODO QCOMPARE(m_axis->axisPen(), axisPen);
@@ -203,7 +204,8 @@ void tst_QAbstractAxis::gridLinePen()
     QCOMPARE(spy10.count(), 0);
     QCOMPARE(spy11.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
     //TODO QCOMPARE(m_axis->gridLinePen(), gridLinePen);
@@ -253,7 +255,8 @@ void tst_QAbstractAxis::minorGridLinePen()
     QCOMPARE(spy10.count(), 0);
     QCOMPARE(spy11.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
 
@@ -301,7 +304,8 @@ void tst_QAbstractAxis::lineVisible()
     QCOMPARE(spy10.count(), 0);
     QCOMPARE(spy11.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
     QCOMPARE(m_axis->isLineVisible(), lineVisible);
@@ -345,7 +349,8 @@ void tst_QAbstractAxis::gridLineVisible()
     QCOMPARE(spy8.count(), 0);
     QCOMPARE(spy9.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
     QCOMPARE(m_axis->isGridLineVisible(), gridLineVisible);
@@ -394,7 +399,8 @@ void tst_QAbstractAxis::minorGridLineVisible()
     QCOMPARE(spy10.count(), 0);
     QCOMPARE(spy11.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
     QCOMPARE(m_axis->isMinorGridLineVisible(), minorGridLineVisible);
@@ -442,7 +448,8 @@ void tst_QAbstractAxis::gridLineColor()
     QCOMPARE(spy10.count(), 1);
     QCOMPARE(spy11.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
 
@@ -489,7 +496,8 @@ void tst_QAbstractAxis::minorGridLineColor()
     QCOMPARE(spy10.count(), 0);
     QCOMPARE(spy11.count(), 1);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
 
@@ -537,7 +545,8 @@ void tst_QAbstractAxis::visible()
     QCOMPARE(spy10.count(), 0);
     QCOMPARE(spy11.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
     QCOMPARE(m_axis->isVisible(), visible);
@@ -584,7 +593,8 @@ void tst_QAbstractAxis::labelsAngle()
     QCOMPARE(spy10.count(), 0);
     QCOMPARE(spy11.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
     QCOMPARE(m_axis->labelsAngle(), labelsAngle);
@@ -738,7 +748,8 @@ void tst_QAbstractAxis::labelsVisible()
     QCOMPARE(spy10.count(), 0);
     QCOMPARE(spy11.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
     QCOMPARE(m_axis->labelsVisible(), labelsVisible);
@@ -769,9 +780,11 @@ void tst_QAbstractAxis::orientation()
     QSignalSpy spy11(m_axis, SIGNAL(minorGridLineColorChanged(QColor)));
 
     if(orientation==Qt::Vertical){
-        m_chart->setAxisY(m_axis,m_series);
+        m_chart->addAxis(m_axis, Qt::AlignLeft);
+        m_series->attachAxis(m_axis);
     }else{
-        m_chart->setAxisX(m_axis,m_series);
+        m_chart->addAxis(m_axis, Qt::AlignBottom);
+        m_series->attachAxis(m_axis);
     }
     QCOMPARE(m_axis->orientation(), orientation);
 
@@ -948,7 +961,8 @@ void tst_QAbstractAxis::shadesPen()
     QCOMPARE(spy10.count(), 0);
     QCOMPARE(spy11.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
     QCOMPARE(m_axis->shadesPen(), shadesPen);
@@ -996,7 +1010,8 @@ void tst_QAbstractAxis::shadesVisible()
     QCOMPARE(spy10.count(), 0);
     QCOMPARE(spy11.count(), 0);
 
-    m_chart->setAxisX(m_axis, m_series);
+    m_chart->addAxis(m_axis, Qt::AlignBottom);
+    m_series->attachAxis(m_axis);
     m_view->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_view));
     QCOMPARE(m_axis->shadesVisible(), shadesVisible);
